monkey.ci.ext.junit

Main namespace for the junit extension. It can be used to read the contents of the junit.xml test result file, and converts it to a format that can be used in MonkeyCI job results.

Main namespace for the junit extension.  It can be used to read the
contents of the `junit.xml` test result file, and converts it to a
format that can be used in MonkeyCI job results.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries