monkey.ci.ext.junit

Main namespace for the junit extension. It can be used to read the contents of the junit.xml test result file, and converts it to a format that can be used in MonkeyCI job results.

Main namespace for the junit extension.  It can be used to read the
contents of the `junit.xml` test result file, and converts it to a
format that can be used in MonkeyCI job results.
raw docstring

artifactclj

(artifact id path)

Creates an artifact definition that can be configured on the job that outputs junit results, but you can also use monkey.ci.api/artifact.

Creates an artifact definition that can be configured on the job that outputs 
junit results, but you can also use `monkey.ci.api/artifact`.
sourceraw docstring

AsPatterncljprotocol

->re-patternclj

(->re-pattern x)
source

handle-tagcljmultimethod

source

junitclj

(junit job)
(junit job art)

Gets or sets the junit artifact on the job

Gets or sets the junit artifact on the job
sourceraw docstring

parse-xmlclj

(parse-xml xml)
source

parse-xmlsclj

(parse-xmls xmls)

Parses and consolidates multiple xml files

Parses and consolidates multiple xml files
sourceraw docstring

read-artifactclj

(read-artifact job id & [path])

Convenience function that configures the junit extension to read the test results from the given artifact. If no path is given, junit.xml is assumed.

Convenience function that configures the junit extension to read the test results from
the given artifact.  If no path is given, `junit.xml` is assumed.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries