Main namespace for the junit extension. It can be used to read the
contents of the junit.xml test result file, and converts it to a
format that can be used in MonkeyCI job results.
Main namespace for the junit extension. It can be used to read the contents of the `junit.xml` test result file, and converts it to a format that can be used in MonkeyCI job results.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |