Main namespace for the junit extension. It can be used to read the
contents of the junit.xml test result file, and converts it to a
format that can be used in MonkeyCI job results.
Main namespace for the junit extension. It can be used to read the contents of the `junit.xml` test result file, and converts it to a format that can be used in MonkeyCI job results.
(artifact id path)Creates an artifact definition that can be configured on the job that outputs
junit results, but you can also use monkey.ci.api/artifact.
Creates an artifact definition that can be configured on the job that outputs junit results, but you can also use `monkey.ci.api/artifact`.
(junit job)(junit job art)Gets or sets the junit artifact on the job
Gets or sets the junit artifact on the job
(parse-xmls xmls)Parses and consolidates multiple xml files
Parses and consolidates multiple xml files
(read-artifact job id & [path])Convenience function that configures the junit extension to read the test results from
the given artifact. If no path is given, junit.xml is assumed.
Convenience function that configures the junit extension to read the test results from the given artifact. If no path is given, `junit.xml` is assumed.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |